@@ -33,7 +33,9 @@ class HttpSensor(BaseSensorOperator):
 
     HTTP Error codes other than 404 (like 403) or Connection Refused Error
     would raise an exception and fail the sensor itself directly (no more poking).
-    To avoid failing the task for other codes than 404, the argument ``extra_option``
+    To avoid failing the task for other codes than 404, the argument ``response_error_codes_allowlist``
+    can be passed with the list containing all the allowed error status codes, like ``["404", "503"]``
+    To skip error status code check at all, the argument ``extra_option``
     can be passed with the value ``{'check_response': False}``. It will make the ``response_check``
     be execute for any http status code.
 
@@ -62,6 +64,9 @@ class HttpSensor(BaseSensorOperator):
     :param endpoint: The relative part of the full url
     :param request_params: The parameters to be added to the GET url
     :param headers: The HTTP headers to be added to the GET request
+    :param response_error_codes_allowlist: An allowlist to return False on poke(), not to raise exception.
+        If the ``None`` value comes in, it is assigned ["404"] by default, for backward compatibility.
+        When you also want ``404 Not Found`` to raise the error, explicitly deliver the blank list ``[]``.
     :param response_check: A check against the 'requests' response object.
         The callable takes the response object as the first positional argument
         and optionally any number of keyword arguments available in the context dictionary.
@@ -85,6 +90,7 @@ class HttpSensor(BaseSensorOperator):
         method: str = "GET",
         request_params: dict[str, Any] | None = None,
         headers: dict[str, Any] | None = None,
+        response_error_codes_allowlist: list[str] | None = None,
         response_check: Callable[..., bool] | None = None,
         extra_options: dict[str, Any] | None = None,
         tcp_keep_alive: bool = True,
@@ -97,6 +103,9 @@ class HttpSensor(BaseSensorOperator):
         self.endpoint = endpoint
         self.http_conn_id = http_conn_id
         self.method = method
+        self.response_error_codes_allowlist = (
+            ("404",) if response_error_codes_allowlist is None else tuple(response_error_codes_allowlist)
+        )
         self.request_params = request_params or {}
         self.headers = headers or {}
         self.extra_options = extra_options or {}
@@ -130,7 +139,7 @@ class HttpSensor(BaseSensorOperator):
                 kwargs = determine_kwargs(self.response_check, [response], context)
                 return self.response_check(response, **kwargs)
         except AirflowException as exc:
-            if str(exc).startswith("404"):
+            if str(exc).startswith(self.response_error_codes_allowlist):
                 return False
 
             raise exc
